﻿using System;
using System.IO;
using Microsoft.Office.Interop.PowerPoint;
using Microsoft.Office.Core;

namespace ppt2img
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length != 4)
            {
                Console.WriteLine("PowerPointファイルを画像に変換します");
                Console.WriteLine();
                Console.WriteLine("ppt2img [PowerPointファイル] [画像形式] [幅] [高さ]");
                Console.WriteLine("例) ppt2img test.ppt png 640 480");
                return;
            }
            // 引数を読み込む
            string filename = Path.GetFullPath(args[0]);
            string filetype = args[1];
            int width = Convert.ToInt32(args[2]);
            int height = Convert.ToInt32(args[3]);

            // PowerPointファイルを開く
            ApplicationClass app = new ApplicationClass();
            Presentation ppt = app.Presentations.Open(filename,
                MsoTriState.msoFalse,
                MsoTriState.msoFalse,
                MsoTriState.msoFalse);

            // スライド枚数を取得
            int slides = ppt.Slides.Count;

            // 保存先作成
            string outputPath = Directory.GetCurrentDirectory() + @"\output\";
            Directory.CreateDirectory(outputPath);

            // 画像として出力
            for (int i = 1; i <= slides; i++)
            {
                string outputName = outputPath + "p"
                    +i.ToString().PadLeft(5,'0') + "." + filetype;
                ppt.Slides[i].Export(outputName, filetype, width, height);
            }

            // 後処理
            ppt.Close();
        }
    }
}
